@@ -1,6 +1,6 @@
 use v6;
 
-unit module TAP:ver<0.0.4>;
+unit module TAP:ver<0.0.6>;
 
 role Entry {
     has Str:D $.raw is required handles <Str>;
@@ -527,7 +527,9 @@ class Reporter::Text does Reporter {
 }
 
 class Formatter::Console is Formatter::Text {
-    my &colored = try { EVAL q{ use Terminal::ANSIColor; &colored } } // sub ($text, $) { $text }
+    my &colored = (try require Terminal::ANSIColor) === Nil
+        ?? sub ($text, $) { $text }
+        !! ::('Terminal::ANSIColor::EXPORT::DEFAULT::&colored');
     method format-success(Str $output) {
         colored($output, 'green');
     }
